==> ozacc-mail-1.1.5-src.tar.gz: ozacc-mail-1.1.5/src/test/com/ozacc/mail/impl/SendMailImplRealTest.java <==
package com.ozacc.mail.impl;

import junit.framework.TestCase;

import org.apache.log4j.BasicConfigurator;

import com.ozacc.mail.Mail;
import com.ozacc.mail.MailBuilder;

/**
 * SendMailImpl饹Υƥȥºݤ᡼顼ǼƳǧƥȤǤ
 * 
 * @author Tomohiro Otsuka
 * @version $Id: SendMailImplRealTest.java,v 1.6 2004/09/20 21:44:01 otsuka Exp $
 */
public class SendMailImplRealTest extends TestCase {

	private MailBuilder builder;

	private String email;

	private SendMailImpl sendMail;

	/*
	 * @see TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		super.setUp();

		BasicConfigurator.configure();

		email = "to@example.com";

		String host = "192.168.0.10";
		sendMail = new SendMailImpl(host);
		sendMail.setMessageId("example.com");

		builder = new XMLMailBuilderImpl();
	}

	/**
	 * @see junit.framework.TestCase#tearDown()
	 */
	protected void tearDown() throws Exception {
		BasicConfigurator.resetConfiguration();
	}

	/*	public void testSendMailWithAttachmentInputStream() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);

	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
	 FileInputStream fis = new FileInputStream(image1);

	 mail.addFile(fis, "ڲ.jpg");
	 mail.setSubject("źեեInputStreamƥ");

	 sendMail.send(mail);
	 }

	 public void testSendMailSimpl() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);

	 sendMail.send(mail);
	 }

	 public void testSendMailWithAttachmentFile() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);

	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
	 File image2 = new File("src/test/com/ozacc/mail/image2.png");

	 mail.addFile(image1);
	 mail.addFile(image2, "ڲ.png");
	 mail.setSubject("źեեƥ");

	 sendMail.send(mail);
	 }

	 public void testSendMailHTML() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail5-html.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.setHtmlText(mail.getText());
	 mail.setText("ץ졼ƥ");
	 sendMail.send(mail);
	 }
	 
	 public void testSendMailHTMLOnly() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail5-html.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.setHtmlText(mail.getText());
	 mail.setText(null);
	 mail.setSubject("HTML꡼");
	 sendMail.send(mail);
	 }

	 public void testSendMailHTMLWithAttachmentFile() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail5-html.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.setHtmlText(mail.getText());
	 mail.setText("ץ졼ƥ");

	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
	 mail.addFile(image1);

	 sendMail.send(mail);
	 }
	 */
	/**
	 * ƥȥҤȤĤʤȥ顼ˤʤΤǡߡ
	 */
	public void testSendMailSuccess() {
		Mail mail;
		assertTrue(true);
	}

}

==> ozacc-mail-1.2-rc6-src.tar.gz: ozacc-mail-1.2-rc6/src/test/com/ozacc/mail/impl/SendMailImplRealTest.java <==
package com.ozacc.mail.impl;

import junit.framework.TestCase;

import org.apache.log4j.BasicConfigurator;

import com.ozacc.mail.Mail;
import com.ozacc.mail.MailBuilder;

/**
 * SendMailImpl饹Υƥȥºݤ᡼顼ǼƳǧƥȤǤ
 * 
 * @author Tomohiro Otsuka
 * @version $Id: SendMailImplRealTest.java,v 1.6.2.1 2005/01/23 06:51:56 otsuka Exp $
 */
public class SendMailImplRealTest extends TestCase {

	private MailBuilder builder;

	private String email;

	private String envelopeTo;

	private SendMailImpl sendMail;

	/*
	 * @see TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		super.setUp();

		BasicConfigurator.configure();

		email = "to@example.com";
		envelopeTo = "to@example.com";

		String host = "localhost";
		sendMail = new SendMailImpl(host);
		sendMail.setMessageId("example.com");

		builder = new XMLMailBuilderImpl();
	}

	/**
	 * @see junit.framework.TestCase#tearDown()
	 */
	protected void tearDown() throws Exception {
		BasicConfigurator.resetConfiguration();
	}

	/*
	 public void testSendMailWithAttachmentInputStream() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);

	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
	 FileInputStream fis = new FileInputStream(image1);

	 mail.addFile(fis, "ڲ.jpg");
	 mail.setSubject("źեեInputStreamƥ");

	 sendMail.send(mail);
	 }

	 
	 public void testSendMailEnvelopeTo() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.addEnvelopeTo(envelopeTo);
	 sendMail.send(mail);
	 }

	 public void testSendMailSimpl() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);

	 sendMail.send(mail);
	 }

	 public void testSendMailWithAttachmentFile() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail4.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);

	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
	 File image2 = new File("src/test/com/ozacc/mail/image2.png");

	 mail.addFile(image1);
	 mail.addFile(image2, "ڲ.png");
	 mail.setSubject("źեեƥ");

	 sendMail.send(mail);
	 }

	 public void testSendMailHTML() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail5-html.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.setHtmlText(mail.getText());
	 mail.setText("ץ졼ƥ");
	 sendMail.send(mail);
	 }
	 
	 public void testSendMailHTMLOnly() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail5-html.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.setHtmlText(mail.getText());
	 mail.setText(null);
	 mail.setSubject("HTML꡼");
	 sendMail.send(mail);
	 }

	 public void testSendMailHTMLWithAttachmentFile() throws Exception {
	 String classPath = "/com/ozacc/mail/test-mail5-html.xml";
	 Mail mail = builder.buildMail(classPath);
	 mail.addTo(email);
	 mail.setHtmlText(mail.getText());
	 mail.setText("ץ졼ƥ");

	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
	 mail.addFile(image1);

	 sendMail.send(mail);
	 }
	 */
	/**
	 * ƥȥҤȤĤʤȥ顼ˤʤΤǡߡ
	 */
	public void testSendMailSuccess() {
		Mail mail;
		assertTrue(true);
	}

}
